<?php
/**
 * @file
 * Drush integration for File Redirect.
 */
/**
 * Implements hook_drush_command().
 */
function file_redirect_drush_command() {
  $items['file-redirect'] = array(
    'description' => dt('Set the production base URL to redirect missing file requests.'),
    'arguments' => array('url' => 'The production URL'),
  );

  return $items;
}

/**
 * Command Callback: file-redirect
 */
function drush_file_redirect($url = '') {
  variable_set('file_redirect_production_host', rtrim($url, '/'));
  file_redirect_create_htaccess();
}

/**
 * Implements drush_hook_COMMAND_validate().
 */
function drush_file_redirect_validate($url = '') {
  if (empty($url)) {
    return drush_set_error('INVALID_URL', dt('You must specify a URL.'));
  }

  if (!preg_match('#^http(s)?://#', $url)) {
    return drush_set_error('INVALID_URL', dt('URL must begin with a valid protocol (ex. http://).', array('!url' => $url)));
  }

  if (!valid_url($url)) {
    return drush_set_error('INVALID_URL', dt('URL !url is not valid.', array('!url' => $url)));
  }
}
